#!/bin/sh

# Internationalization.
. /usr/bin/gettext.sh
TEXTDOMAIN='slitaz-base'
. /etc/locale.conf
export TEXTDOMAIN LANG
. /usr/lib/slitaz/httphelper.sh

icon_type() {
	local icon=unknown
	case $1 in
		..)				icon=go-up ;;
		*/)				icon=folder ;;
		*.mp3)			icon=mp3 ;;
		*.ogg)			icon=ogg ;;
		*.wma)			icon=wma ;;
		*.wav)			icon=wav ;;
		*.m4a|*.flac)	icon=audio ;;
		*.jpg|*.jpeg)	icon=jpg ;;
		*.png)			icon=png ;;
		*.avi|*.mp4|*.mkv|*.mpg|*.wmv)	icon=video ;;
		*.flv)			icon=flv ;;
		*.swf)			icon=flash ;;
	esac
	echo "/content/icons/$icon.png"
}

cur_folder=$(basename "${QUERY_STRING#/content/}")

if [ ! -d "..$QUERY_STRING" ]; then
	cat <<EOT
HTTP/1.1 404 Not Found
Content-type: text/html

<html><head><meta charset="utf-8" /><title>Заблудились?</title></head>
<body>Здесь ничего нет!</body></html>
EOT
	exit 1
fi

cat <<EOT
HTTP/1.1 200 OK
Content-type: text/html

<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<title>${QUERY_STRING#/content/}</title>
	<meta charset="utf-8" />
	<meta name="viewport" content="width=device-width,minimum-scale=1.0">
	<link rel="stylesheet" type="text/css" href="/style.css" />
</head>
<body>

<header>
	<h1><img src="/content/icons/folder.png" />$cur_folder</h1>
</header>

<div id="content">
EOT


[ "$QUERY_STRING" != "/" ] && echo "<a href=\"..\"><div class=\"but\"><img src=\"$(icon_type ..)\" /><div>Вверх</div></div></a>"

IFS=$'\n'

# folders
for line in $(ls -p "..$QUERY_STRING" | sed -n '/.*\/$/p'); do
	if [ -e "/var/www$QUERY_STRING$line/folder.jpg" ]; then
		icon="$QUERY_STRING$line/folder.jpg"
	elif [ -e "/var/www$QUERY_STRING$line/cover.jpg" ]; then
		icon="$QUERY_STRING$line/cover.jpg"
	else
		icon="$(ls -p /var/www$QUERY_STRING$line/*.jpg | head -n1 | sed 's|/var/www||')"
	fi
	if [ "x$icon" == x ]; then
		icon=$(icon_type /)
	fi
	echo "<a href=\"$line\"><div class=\"but\"><img src=\"$icon\" /><strong>${line%/}</strong></div></a>"
done
# files
for line in $(ls -p "..$QUERY_STRING" | sed '/.*\/$/d'); do
	echo "<a href=\"$line\"><div class=\"but\"><img src=\"$(icon_type "$line")\" /><div>$line</div></div></a>"
done

cat <<EOT
</div>

<!-- pre>$(httpinfo)</pre -->

<footer>
	Мой домашний медиа-сервер<br />работает на <a href="http://www.slitaz.org/">SliTaz GNU/Linux</a>
</footer>

</body>
</html>
EOT
